package com.admogo.adapters;

import android.util.Log;
import com.admogo.AdMogoLayout;
import com.admogo.obj.Ration;
import com.admogo.util.AdMogoUtil;
import java.lang.ref.WeakReference;
import java.lang.reflect.InvocationTargetException;
/* loaded from: classes.dex */
public abstract class AdMogoAdapter {

    /* renamed from: adapter  reason: collision with root package name */
    static AdMogoAdapter f0adapter;
    protected final WeakReference<AdMogoLayout> adMogoLayoutReference;
    protected Ration ration;

    public abstract void finish();

    public abstract void handle();

    public AdMogoAdapter(AdMogoLayout adMogoLayout, Ration ration) {
        this.adMogoLayoutReference = new WeakReference<>(adMogoLayout);
        this.ration = ration;
    }

    private static AdMogoAdapter getAdapter(AdMogoLayout adMogoLayout, Ration ration) {
        AdMogoAdapter unknownAdNetwork;
        try {
            switch (ration.type) {
                case 1:
                    if (Class.forName("com.google.ads.AdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.GoogleAdMobAdsAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case 2:
                case 3:
                case 4:
                case 5:
                case 8:
                case AdMogoUtil.NETWORK_TYPE_ADMOGO /* 10 */:
                case AdMogoUtil.NETWORK_TYPE_MOBCLIX /* 11 */:
                case AdMogoUtil.NETWORK_TYPE_4THSCREEN /* 13 */:
                case AdMogoUtil.NETWORK_TYPE_ADSENSE /* 14 */:
                case AdMogoUtil.NETWORK_TYPE_DOUBLECLICK /* 15 */:
                case AdMogoUtil.NETWORK_TYPE_GENERIC /* 16 */:
                case AdMogoUtil.NETWORK_TYPE_EVENT /* 17 */:
                case 19:
                case 31:
                case AdMogoUtil.NETWORK_TYPE_AIRAD /* 32 */:
                default:
                    unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                    break;
                case 6:
                    if (Class.forName("com.millennialmedia.android.MMAdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.MillennialAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case 7:
                    if (Class.forName("com.greystripe.android.sdk.BannerView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.GreystripeAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_CUSTOM /* 9 */:
                    unknownAdNetwork = new CustomAdapter(adMogoLayout, ration);
                    break;
                case AdMogoUtil.NETWORK_TYPE_MDOTM /* 12 */:
                    unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.MdotMAdapter", adMogoLayout, ration);
                    break;
                case AdMogoUtil.NETWORK_TYPE_INMOBI /* 18 */:
                    if (Class.forName("com.inmobi.androidsdk.impl.InMobiAdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.InMobiAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_ZESTADZ /* 20 */:
                    if (Class.forName("com.zestadz.android.ZestADZAdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.ZestAdzAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_ADCHINA /* 21 */:
                    if (Class.forName("com.adchina.android.ads.views.AdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.AdChinaAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_WIYUN /* 22 */:
                    if (Class.forName("com.wiyun.ad.AdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.WiyunAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_WOOBOO /* 23 */:
                    if (Class.forName("com.wooboo.adlib_android.WoobooAdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.WoobooAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_YOUMI /* 24 */:
                    if (Class.forName("net.youmi.android.AdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.YoumiAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_CASEE /* 25 */:
                    if (Class.forName("com.casee.adsdk.CaseeAdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.CaseeAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_SMART /* 26 */:
                    if (Class.forName("com.madhouse.android.ads.AdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.SmartMADAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_MOGO /* 27 */:
                    unknownAdNetwork = new MogoAdapter(adMogoLayout, ration);
                    break;
                case AdMogoUtil.NETWORK_TYPE_ADTOUCH /* 28 */:
                    if (Class.forName("com.energysource.szj.embeded.AdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.AdTouchAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_DOMOB /* 29 */:
                    if (Class.forName("cn.domob.android.ads.DomobAdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.DomobAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_VPON /* 30 */:
                    if (Class.forName("com.vpon.adon.android.AdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.VponCNAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_ADWO /* 33 */:
                    if (Class.forName("com.adwo.adsdk.AdwoAdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.AdwoAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_LSENSE /* 34 */:
                    if (Class.forName("com.l.adlib_android.AdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.LSenseAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_SMAATO /* 35 */:
                    if (Class.forName("com.smaato.SOMA.SOMABanner") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.SmaatoAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
                case AdMogoUtil.NETWORK_TYPE_APPMEDIA /* 36 */:
                    if (Class.forName("cn.appmedia.ad.BannerAdView") != null) {
                        unknownAdNetwork = getNetworkAdapter("com.admogo.adapters.AppMediaAdapter", adMogoLayout, ration);
                        break;
                    } else {
                        unknownAdNetwork = unknownAdNetwork(adMogoLayout, ration);
                        break;
                    }
            }
            return unknownAdNetwork;
        } catch (ClassNotFoundException e) {
            return unknownAdNetwork(adMogoLayout, ration);
        } catch (VerifyError e2) {
            Log.e("AdMogo", "Caught VerifyError", e2);
            return unknownAdNetwork(adMogoLayout, ration);
        }
    }

    private static AdMogoAdapter getNetworkAdapter(String networkAdapter, AdMogoLayout adMogoLayout, Ration ration) {
        try {
            Class[] parameterTypes = {AdMogoLayout.class, Ration.class};
            Object[] args = {adMogoLayout, ration};
            AdMogoAdapter adMogoAdapter = (AdMogoAdapter) Class.forName(networkAdapter).getConstructor(parameterTypes).newInstance(args);
            return adMogoAdapter;
        } catch (ClassNotFoundException e) {
            return null;
        } catch (IllegalAccessException e2) {
            return null;
        } catch (InstantiationException e3) {
            return null;
        } catch (NoSuchMethodException e4) {
            return null;
        } catch (SecurityException e5) {
            return null;
        } catch (InvocationTargetException e6) {
            return null;
        }
    }

    private static AdMogoAdapter unknownAdNetwork(AdMogoLayout adMogoLayout, Ration ration) {
        Log.w(AdMogoUtil.ADMOGO, "Unsupported ration type: " + ration.type);
        return null;
    }

    public static void handle(AdMogoLayout adMogoLayout, Ration ration) throws Throwable {
        if (f0adapter != null) {
            f0adapter.finish();
        }
        f0adapter = getAdapter(adMogoLayout, ration);
        if (f0adapter != null) {
            Log.d(AdMogoUtil.ADMOGO, "Valid adapter, calling handle()");
            f0adapter.handle();
            return;
        }
        throw new Exception("Invalid adapter");
    }
}
