package com.admogo.adapters;

import android.app.Activity;
import android.graphics.Color;
import android.graphics.Typeface;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.GradientDrawable;
import android.util.Log;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;
import com.admogo.AdMogoLayout;
import com.admogo.obj.Ration;
import com.admogo.util.AdMogoUtil;
import com.madhouse.android.ads.AdView;
import java.io.IOException;
import java.io.InputStream;
import java.util.concurrent.TimeUnit;
/* loaded from: classes.dex */
public class MogoAdapter extends AdMogoAdapter {
    public MogoAdapter(AdMogoLayout adMogoLayout, Ration ration) {
        super(adMogoLayout, ration);
    }

    @Override // com.admogo.adapters.AdMogoAdapter
    public void handle() {
        AdMogoLayout adMogoLayout = this.adMogoLayoutReference.get();
        if (adMogoLayout != null) {
            adMogoLayout.scheduler.schedule(new FetchMogoRunnable(this), 0L, TimeUnit.SECONDS);
        }
    }

    public void displayMogo() {
        Activity activity;
        AdMogoLayout adMogoLayout = this.adMogoLayoutReference.get();
        if (adMogoLayout != null && (activity = adMogoLayout.activityReference.get()) != null) {
            switch (adMogoLayout.mogo.type) {
                case 1:
                    Log.d(AdMogoUtil.ADMOGO, "Serving Mogo type: banner");
                    RelativeLayout bannerView = new RelativeLayout(activity);
                    if (adMogoLayout.mogo.image == null) {
                        adMogoLayout.rotateThreadedNow();
                        return;
                    }
                    ImageView bannerImageView = new ImageView(activity);
                    bannerImageView.setImageDrawable(adMogoLayout.mogo.image);
                    RelativeLayout.LayoutParams bannerViewParams = new RelativeLayout.LayoutParams(-2, -2);
                    bannerViewParams.addRule(13);
                    bannerView.addView(bannerImageView, bannerViewParams);
                    adMogoLayout.pushSubView(bannerView, 27);
                    break;
                case 2:
                    Log.d(AdMogoUtil.ADMOGO, "Serving Mogo type: icon");
                    RelativeLayout iconView = new RelativeLayout(activity);
                    if (adMogoLayout.mogo.image == null) {
                        adMogoLayout.rotateThreadedNow();
                        return;
                    }
                    double density = AdMogoUtil.getDensity(activity);
                    double px320 = AdMogoUtil.convertToScreenPixels((int) AdView.AD_MEASURE_320, density);
                    double px50 = AdMogoUtil.convertToScreenPixels(50, density);
                    double px4 = AdMogoUtil.convertToScreenPixels(4, density);
                    double px6 = AdMogoUtil.convertToScreenPixels(6, density);
                    iconView.setLayoutParams(new FrameLayout.LayoutParams((int) px320, (int) px50));
                    ImageView blendView = new ImageView(activity);
                    int backgroundColor = Color.rgb(adMogoLayout.extra.bgRed, adMogoLayout.extra.bgGreen, adMogoLayout.extra.bgBlue);
                    GradientDrawable blend = new GradientDrawable(GradientDrawable.Orientation.TOP_BOTTOM, new int[]{-1, backgroundColor, backgroundColor, backgroundColor});
                    blendView.setBackgroundDrawable(blend);
                    RelativeLayout.LayoutParams blendViewParams = new RelativeLayout.LayoutParams(-1, -1);
                    iconView.addView(blendView, blendViewParams);
                    ImageView iconImageView = new ImageView(activity);
                    iconImageView.setImageDrawable(adMogoLayout.mogo.image);
                    iconImageView.setId(10);
                    iconImageView.setPadding((int) px4, 0, (int) px6, 0);
                    iconImageView.setScaleType(ImageView.ScaleType.CENTER);
                    RelativeLayout.LayoutParams iconViewParams = new RelativeLayout.LayoutParams(-2, -1);
                    iconView.addView(iconImageView, iconViewParams);
                    ImageView frameImageView = new ImageView(activity);
                    InputStream drawableStream = getClass().getResourceAsStream("/com/admogo/assets/ad_frame.gif");
                    new BitmapDrawable(drawableStream);
                    frameImageView.setImageDrawable(null);
                    frameImageView.setPadding((int) px4, 0, (int) px6, 0);
                    frameImageView.setScaleType(ImageView.ScaleType.CENTER);
                    RelativeLayout.LayoutParams frameViewParams = new RelativeLayout.LayoutParams(-2, -1);
                    iconView.addView(frameImageView, frameViewParams);
                    TextView iconTextView = new TextView(activity);
                    try {
                        if (adMogoLayout.mogo.description == null) {
                        }
                    } catch (Exception e) {
                        adMogoLayout.mogo.description = "Haven't description!";
                    }
                    iconTextView.setText(adMogoLayout.mogo.description);
                    iconTextView.setTypeface(Typeface.DEFAULT_BOLD, 1);
                    iconTextView.setTextColor(Color.rgb(adMogoLayout.extra.fgRed, adMogoLayout.extra.fgGreen, adMogoLayout.extra.fgBlue));
                    RelativeLayout.LayoutParams textViewParams = new RelativeLayout.LayoutParams(-1, -1);
                    textViewParams.addRule(1, iconImageView.getId());
                    textViewParams.addRule(10);
                    textViewParams.addRule(12);
                    textViewParams.addRule(15);
                    textViewParams.addRule(13);
                    iconTextView.setGravity(16);
                    iconView.addView(iconTextView, textViewParams);
                    adMogoLayout.pushSubView(iconView, 27);
                    try {
                        drawableStream.close();
                        break;
                    } catch (IOException e2) {
                        Log.e(AdMogoUtil.ADMOGO, e2.toString());
                        break;
                    }
                default:
                    Log.w(AdMogoUtil.ADMOGO, "Unknown mogo type!");
                    adMogoLayout.rotateThreadedNow();
                    return;
            }
            adMogoLayout.mogo.image = null;
            adMogoLayout.adMogoManager.resetRollover();
            adMogoLayout.rotateThreadedDelayed();
        }
    }

    /* loaded from: classes.dex */
    private static class FetchMogoRunnable implements Runnable {
        private MogoAdapter mogoAdapter;

        public FetchMogoRunnable(MogoAdapter mogoAdapter) {
            this.mogoAdapter = mogoAdapter;
        }

        @Override // java.lang.Runnable
        public void run() {
            AdMogoLayout adMogoLayout = this.mogoAdapter.adMogoLayoutReference.get();
            if (adMogoLayout != null) {
                adMogoLayout.mogo = adMogoLayout.adMogoManager.getMogo(this.mogoAdapter.ration.nid);
                if (adMogoLayout.mogo == null) {
                    adMogoLayout.rotateThreadedNow();
                } else {
                    adMogoLayout.handler.post(new DisplayMogoRunnable(this.mogoAdapter));
                }
            }
        }
    }

    /* loaded from: classes.dex */
    private static class DisplayMogoRunnable implements Runnable {
        private MogoAdapter mogoAdapter;

        public DisplayMogoRunnable(MogoAdapter mogoAdapter) {
            this.mogoAdapter = mogoAdapter;
        }

        @Override // java.lang.Runnable
        public void run() {
            this.mogoAdapter.displayMogo();
        }
    }

    @Override // com.admogo.adapters.AdMogoAdapter
    public void finish() {
        Log.d(AdMogoUtil.ADMOGO, "Mogo Finished");
    }
}
