package com.vpon.adon.android;

import android.content.Context;
import android.location.Location;
import android.location.LocationListener;
import android.os.Bundle;
import android.os.Handler;
import android.util.Log;
import com.vpon.adon.android.entity.Ad;
import com.vpon.adon.android.entity.AdRedirectPack;
import com.vpon.adon.android.entity.RespClick;
import com.vpon.adon.android.entity.RespClickList;
import com.vpon.adon.android.exception.ServiceUnavailableException;
import com.vpon.adon.android.utils.AdOnJsonUtil;
import com.vpon.adon.android.utils.AdOnServerUtil;
import com.vpon.adon.android.utils.AdOnUrlUtil;
import com.vpon.adon.android.utils.CellTowerUtil;
import com.vpon.adon.android.utils.CryptUtils;
import com.vpon.adon.android.utils.IOUtils;
import com.vpon.adon.android.utils.LocationUtil;
import com.vpon.adon.android.utils.PhoneStateUtils;
import com.vpon.adon.android.utils.VPLog;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.StreamCorruptedException;
import java.net.URISyntaxException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.spec.InvalidKeySpecException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.LinkedList;
import java.util.List;
import javax.crypto.BadPaddingException;
import javax.crypto.IllegalBlockSizeException;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.SealedObject;
import org.apache.http.HttpResponse;
import org.apache.http.ParseException;
import org.apache.http.util.EntityUtils;
import org.json.JSONException;
import org.json.JSONObject;
/* loaded from: classes.dex */
public final class AdManager implements LocationListener {
    private static AdManager instance = null;
    public static final String vponServer = "service@vpon.com";
    private List<AdView> adViews = new LinkedList();
    private Context context;
    private double lat;
    private double lon;
    private List<RespClick> respClicks;
    private Location userLocation;

    private AdManager(Context context) {
        this.context = context;
        LocationUtil.instance(context).addLocationListener(this);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void addAdView(AdView adView) {
        this.adViews.add(adView);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void performAdRequester(final AdView adView, final Handler handler) {
        Runnable adRequester = new Runnable() { // from class: com.vpon.adon.android.AdManager.1
            @Override // java.lang.Runnable
            public void run() {
                synchronized (AdManager.instance) {
                    AdManager.this.adRequester(adView, handler);
                }
            }
        };
        new Thread(adRequester).start();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void adRequester(AdView adView, Handler handler) {
        try {
            JSONObject jsonObject = AdOnJsonUtil.getWebviewAdReqJson(this.context, this.lat, this.lon, adView.getLicenseKey());
            VPLog.i("AdManager", "json: " + jsonObject.toString());
            String url = AdOnUrlUtil.getAdReqUrl(adView.getPlatform());
            HttpResponse httpResp = IOUtils.instance().connectJSONServer(jsonObject.toString(), url, AppConfig.SDKVERSION);
            int reStatus = Integer.valueOf(httpResp.getLastHeader("X-ADON-STATUS").getValue()).intValue();
            if (reStatus != 0) {
                AdOnServerUtil.printErrorLog(reStatus);
                displayNextAd(adView, handler, null);
                return;
            }
            String html = EntityUtils.toString(httpResp.getEntity());
            Ad ad = new Ad();
            ad.setAdHtml(html);
            ad.setAdId(httpResp.getLastHeader("X-ADON-AD_ID").getValue());
            ad.setAdHeight(Integer.valueOf(httpResp.getLastHeader("X-ADON-AD_HEIGHT").getValue()).intValue());
            ad.setAdWidth(Integer.valueOf(httpResp.getLastHeader("X-ADON-AD_WIDTH").getValue()).intValue());
            ad.setRefreshTime(Integer.valueOf(httpResp.getLastHeader("X-ADON-REFRESH_TIME").getValue()).intValue());
            if (httpResp.getLastHeader("X-ADON-LAT") != null) {
                ad.setMapLat(Double.valueOf(httpResp.getLastHeader("X-ADON-LAT").getValue()).doubleValue());
            }
            if (httpResp.getLastHeader("X-ADON-LON") != null) {
                ad.setMapLon(Double.valueOf(httpResp.getLastHeader("X-ADON-LON").getValue()).doubleValue());
            }
            String imei = PhoneStateUtils.getIMEI(this.context);
            String cellId = CellTowerUtil.instance(this.context).getCellId();
            String lac = CellTowerUtil.instance(this.context).getLac();
            String mnc = CellTowerUtil.instance(this.context).getMnc();
            String mcc = CellTowerUtil.instance(this.context).getMcc();
            AdRedirectPack adRedirectPack = new AdRedirectPack();
            adRedirectPack.setAdId(ad.getAdId());
            adRedirectPack.setCellId(cellId);
            adRedirectPack.setImei(imei);
            adRedirectPack.setLac(lac);
            adRedirectPack.setLat(Double.valueOf(this.lat));
            adRedirectPack.setLicensekey(adView.getLicenseKey());
            adRedirectPack.setLon(Double.valueOf(this.lon));
            adRedirectPack.setMcc(mcc);
            adRedirectPack.setMnc(mnc);
            adRedirectPack.setLocation(this.userLocation);
            ad.setAdRedirectPack(adRedirectPack);
            displayNextAd(adView, handler, ad);
        } catch (NoSuchProviderException e) {
            displayNextAd(adView, handler, null);
        } catch (ParseException e2) {
            displayNextAd(adView, handler, null);
        } catch (ServiceUnavailableException e3) {
            displayNextAd(adView, handler, null);
        } catch (IOException e4) {
            displayNextAd(adView, handler, null);
        } catch (URISyntaxException e5) {
            displayNextAd(adView, handler, null);
        } catch (InvalidKeyException e6) {
            displayNextAd(adView, handler, null);
        } catch (NoSuchAlgorithmException e7) {
            displayNextAd(adView, handler, null);
        } catch (InvalidKeySpecException e8) {
            displayNextAd(adView, handler, null);
        } catch (BadPaddingException e9) {
            displayNextAd(adView, handler, null);
        } catch (IllegalBlockSizeException e10) {
            displayNextAd(adView, handler, null);
        } catch (NoSuchPaddingException e11) {
            displayNextAd(adView, handler, null);
        } catch (JSONException e12) {
            displayNextAd(adView, handler, null);
        } catch (Exception e13) {
            displayNextAd(adView, handler, null);
        }
    }

    private void displayNextAd(final AdView adView, Handler handler, final Ad ad) {
        Runnable runnable = new Runnable() { // from class: com.vpon.adon.android.AdManager.2
            @Override // java.lang.Runnable
            public void run() {
                adView.displayNextAd(ad);
            }
        };
        handler.post(runnable);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void performErrorRequester(final AdView adView, final String errorMessage) {
        Runnable errorRequester = new Runnable() { // from class: com.vpon.adon.android.AdManager.3
            @Override // java.lang.Runnable
            public void run() {
                synchronized (AdManager.instance) {
                    AdManager.this.errorRequester(adView, errorMessage);
                }
            }
        };
        new Thread(errorRequester).start();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void errorRequester(AdView adView, String errorMessage) {
        try {
            JSONObject json = AdOnJsonUtil.getErrorJson(this.context, this.lat, this.lon, adView.getLicenseKey(), String.valueOf(adView.getLicenseKey()) + " generate error: " + errorMessage);
            String url = AdOnUrlUtil.getAdErrorUrl(adView.getPlatform());
            IOUtils.instance().connectJSONServer(json.toString(), url, AppConfig.SDKVERSION);
        } catch (ServiceUnavailableException e) {
        } catch (IOException e2) {
        } catch (URISyntaxException e3) {
        } catch (InvalidKeyException e4) {
        } catch (NoSuchAlgorithmException e5) {
        } catch (NoSuchProviderException e6) {
        } catch (InvalidKeySpecException e7) {
        } catch (BadPaddingException e8) {
        } catch (IllegalBlockSizeException e9) {
        } catch (NoSuchPaddingException e10) {
        } catch (Exception e11) {
        } catch (ParseException e12) {
        } catch (JSONException e13) {
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void performClickRequester(final AdView adView, final Ad currentAd) {
        Runnable clickRequester = new Runnable() { // from class: com.vpon.adon.android.AdManager.4
            @Override // java.lang.Runnable
            public void run() {
                synchronized (AdManager.instance) {
                    AdManager.this.clickRequester(adView, currentAd);
                }
            }
        };
        new Thread(clickRequester).start();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void clickRequester(AdView adView, Ad currentAd) {
        SimpleDateFormat setDateFormat = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss z");
        String currentTime = setDateFormat.format(Calendar.getInstance().getTime());
        String cellId = CellTowerUtil.instance(this.context).getCellId();
        String lac = CellTowerUtil.instance(this.context).getLac();
        String mnc = CellTowerUtil.instance(this.context).getMnc();
        String mcc = CellTowerUtil.instance(this.context).getMcc();
        RespClick respClick = new RespClick();
        respClick.setLicenseKey(adView.getLicenseKey());
        respClick.setAdId(currentAd.getAdId());
        respClick.setLat(this.lat);
        respClick.setLon(this.lon);
        respClick.setCellID(cellId);
        respClick.setLac(lac);
        respClick.setMcc(mcc);
        respClick.setMnc(mnc);
        respClick.setTime(currentTime);
        File file = new File(getClickFilePath());
        if (!file.exists()) {
            writeClickListToFile(new RespClickList(new LinkedList()));
        }
        RespClickList respClickList = readClickListFromFile();
        this.respClicks = respClickList.getRespClicks();
        this.respClicks.add(respClick);
        VPLog.i("respClicks size", String.valueOf(this.respClicks.size()));
        sendRespClicks(adView);
    }

    private void sendRespClicks(AdView adView) {
        VPLog.i("AdMAnager", "sendRespClicks");
        ObjectOutputStream oos = null;
        try {
            JSONObject json = AdOnJsonUtil.getClickJson(this.context, this.lat, this.lon, adView.getLicenseKey(), this.respClicks);
            String url = AdOnUrlUtil.getAdClickUrl(adView.getPlatform());
            IOUtils instance2 = IOUtils.instance();
            if (instance2 == null) {
                if (0 != 0) {
                    try {
                        oos.close();
                        return;
                    } catch (IOException e) {
                        e.printStackTrace();
                        return;
                    }
                }
                return;
            }
            String strJson = json.toString();
            HttpResponse httpResp = instance2.connectJSONServer(strJson, url, AppConfig.SDKVERSION);
            int reStatus = Integer.valueOf(httpResp.getLastHeader("X-ADON-STATUS").getValue()).intValue();
            VPLog.i("AdMAnager", "reStatus: " + String.valueOf(reStatus));
            if (reStatus >= 0) {
                this.respClicks = new LinkedList();
            }
            writeClickListToFile(new RespClickList(this.respClicks));
            VPLog.i("respClicks size", String.valueOf(this.respClicks.size()));
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e2) {
                    e2.printStackTrace();
                }
            }
        } catch (ServiceUnavailableException e3) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e4) {
                    e4.printStackTrace();
                }
            }
        } catch (IOException e5) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e6) {
                    e6.printStackTrace();
                }
            }
        } catch (URISyntaxException e7) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e8) {
                    e8.printStackTrace();
                }
            }
        } catch (InvalidKeyException e9) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e10) {
                    e10.printStackTrace();
                }
            }
        } catch (NoSuchAlgorithmException e11) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e12) {
                    e12.printStackTrace();
                }
            }
        } catch (NoSuchProviderException e13) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e14) {
                    e14.printStackTrace();
                }
            }
        } catch (InvalidKeySpecException e15) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e16) {
                    e16.printStackTrace();
                }
            }
        } catch (BadPaddingException e17) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e18) {
                    e18.printStackTrace();
                }
            }
        } catch (IllegalBlockSizeException e19) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e20) {
                    e20.printStackTrace();
                }
            }
        } catch (NoSuchPaddingException e21) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e22) {
                    e22.printStackTrace();
                }
            }
        } catch (JSONException e23) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e24) {
                    e24.printStackTrace();
                }
            }
        } catch (Exception e25) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e26) {
                    e26.printStackTrace();
                }
            }
        } catch (ParseException e27) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e28) {
                    e28.printStackTrace();
                }
            }
        } catch (Throwable th) {
            if (0 != 0) {
                try {
                    oos.close();
                } catch (IOException e29) {
                    e29.printStackTrace();
                }
            }
            throw th;
        }
    }

    private void writeClickListToFile(RespClickList respClickList) {
        IOException e;
        FileNotFoundException e2;
        File file = new File(getClickFilePath());
        ObjectOutputStream oos = null;
        FileOutputStream fos = null;
        try {
            try {
                fos = new FileOutputStream(file);
                try {
                    ObjectOutputStream oos2 = new ObjectOutputStream(new FileOutputStream(file));
                    try {
                        SealedObject sealedObject = CryptUtils.clickListEnc("http://www.vpon.com/v/index.jsp88623698333service@vpon.com", respClickList);
                        oos2.writeObject(sealedObject);
                        oos2.flush();
                        try {
                            try {
                                oos2.close();
                                try {
                                    fos.close();
                                    fos = fos;
                                    oos = oos2;
                                } catch (IOException e3) {
                                    e3.printStackTrace();
                                    fos = fos;
                                    oos = oos2;
                                }
                            } finally {
                            }
                        } catch (IOException e4) {
                            e4.printStackTrace();
                            try {
                                fos.close();
                                fos = fos;
                                oos = oos2;
                            } catch (IOException e5) {
                                e5.printStackTrace();
                                fos = fos;
                                oos = oos2;
                            }
                        }
                    } catch (FileNotFoundException e6) {
                        e2 = e6;
                        fos = fos;
                        oos = oos2;
                        e2.printStackTrace();
                        try {
                            try {
                                oos.close();
                                try {
                                    fos.close();
                                } catch (IOException e7) {
                                    e7.printStackTrace();
                                }
                            } catch (IOException e8) {
                                e8.printStackTrace();
                                try {
                                    fos.close();
                                } catch (IOException e9) {
                                    e9.printStackTrace();
                                }
                            }
                        } finally {
                        }
                    } catch (IOException e10) {
                        e = e10;
                        fos = fos;
                        oos = oos2;
                        e.printStackTrace();
                        try {
                            try {
                                oos.close();
                                try {
                                    fos.close();
                                } catch (IOException e11) {
                                    e11.printStackTrace();
                                }
                            } finally {
                                try {
                                    fos.close();
                                } catch (IOException e12) {
                                    e12.printStackTrace();
                                }
                            }
                        } catch (IOException e13) {
                            e13.printStackTrace();
                            try {
                                fos.close();
                            } catch (IOException e14) {
                                e14.printStackTrace();
                            }
                        }
                    } catch (Throwable th) {
                        th = th;
                        fos = fos;
                        oos = oos2;
                        try {
                            try {
                                oos.close();
                                try {
                                    fos.close();
                                } catch (IOException e15) {
                                    e15.printStackTrace();
                                }
                            } catch (IOException e16) {
                                e16.printStackTrace();
                                try {
                                    fos.close();
                                } catch (IOException e17) {
                                    e17.printStackTrace();
                                }
                                throw th;
                            }
                            throw th;
                        } finally {
                            try {
                                fos.close();
                            } catch (IOException e18) {
                                e18.printStackTrace();
                            }
                        }
                    }
                } catch (FileNotFoundException e19) {
                    e2 = e19;
                    fos = fos;
                } catch (IOException e20) {
                    e = e20;
                    fos = fos;
                } catch (Throwable th2) {
                    th = th2;
                    fos = fos;
                }
            } catch (Throwable th3) {
                th = th3;
            }
        } catch (FileNotFoundException e21) {
            e2 = e21;
        } catch (IOException e22) {
            e = e22;
        }
    }

    private RespClickList readClickListFromFile() {
        ClassNotFoundException e;
        IOException e2;
        StreamCorruptedException e3;
        FileNotFoundException e4;
        RespClickList respClickList;
        ObjectInputStream ois;
        File file = new File(getClickFilePath());
        ObjectInputStream ois2 = null;
        try {
            try {
                ois = new ObjectInputStream(new FileInputStream(file));
            } catch (Throwable th) {
                th = th;
            }
        } catch (FileNotFoundException e5) {
            e4 = e5;
        } catch (StreamCorruptedException e6) {
            e3 = e6;
        } catch (IOException e7) {
            e2 = e7;
        } catch (ClassNotFoundException e8) {
            e = e8;
        }
        try {
            Object sealedObject = ois.readObject();
            if (sealedObject == null) {
                VPLog.i("adManger", "sealedObject null");
            }
            respClickList = CryptUtils.clickListDnc("http://www.vpon.com/v/index.jsp88623698333service@vpon.com", (SealedObject) sealedObject);
        } catch (FileNotFoundException e9) {
            e4 = e9;
            ois2 = ois;
            e4.printStackTrace();
            respClickList = new RespClickList(new LinkedList());
            if (ois2 != null) {
                try {
                    ois2.close();
                } catch (IOException e10) {
                    e10.printStackTrace();
                }
            }
            return respClickList;
        } catch (StreamCorruptedException e11) {
            e3 = e11;
            ois2 = ois;
            e3.printStackTrace();
            respClickList = new RespClickList(new LinkedList());
            if (ois2 != null) {
                try {
                    ois2.close();
                } catch (IOException e12) {
                    e12.printStackTrace();
                }
            }
            return respClickList;
        } catch (IOException e13) {
            e2 = e13;
            ois2 = ois;
            e2.printStackTrace();
            respClickList = new RespClickList(new LinkedList());
            if (ois2 != null) {
                try {
                    ois2.close();
                } catch (IOException e14) {
                    e14.printStackTrace();
                }
            }
            return respClickList;
        } catch (ClassNotFoundException e15) {
            e = e15;
            ois2 = ois;
            e.printStackTrace();
            respClickList = new RespClickList(new LinkedList());
            if (ois2 != null) {
                try {
                    ois2.close();
                } catch (IOException e16) {
                    e16.printStackTrace();
                }
            }
            return respClickList;
        } catch (Throwable th2) {
            th = th2;
            ois2 = ois;
            if (ois2 != null) {
                try {
                    ois2.close();
                } catch (IOException e17) {
                    e17.printStackTrace();
                }
            }
            throw th;
        }
        if (ois != null) {
            try {
                ois.close();
                ois2 = ois;
            } catch (IOException e18) {
                e18.printStackTrace();
            }
            return respClickList;
        }
        ois2 = ois;
        return respClickList;
    }

    private String getClickFilePath() {
        return String.valueOf(this.context.getFilesDir().getParent()) + File.separator + "appDataFile";
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static AdManager instance(Context context) {
        if (instance == null) {
            instance = new AdManager(context);
        }
        return instance;
    }

    public void remove() {
        instance = null;
    }

    @Override // android.location.LocationListener
    public void onLocationChanged(Location location) {
        this.userLocation = location;
        this.lat = location.getLatitude();
        this.lon = location.getLongitude();
        Log.v("SDK lat", Double.toString(this.lat));
        Log.v("SDK lon", Double.toString(this.lon));
    }

    @Override // android.location.LocationListener
    public void onProviderDisabled(String provider) {
    }

    @Override // android.location.LocationListener
    public void onProviderEnabled(String provider) {
    }

    @Override // android.location.LocationListener
    public void onStatusChanged(String provider, int status, Bundle extras) {
    }
}
